@@ -28,7 +28,7 @@ KontactConfigureDialog::KontactConfigureDialog(QWidget *parent)
 
 KontactConfigureDialog::~KontactConfigureDialog()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKontactConfigureDialogConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKontactConfigureDialogConfigGroupName));
     group.writeEntry("width", width());
     group.writeEntry("height", height());
 }
@@ -73,8 +73,10 @@ void KontactConfigureDialog::slotOk()
 
 QSize KontactConfigureDialog::sizeHint() const
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKontactConfigureDialogConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKontactConfigureDialogConfigGroupName));
     const int width = group.readEntry("width", 800);
     const int height = group.readEntry("height", 600);
     return QSize(width, height);
 }
+
+#include "moc_kontactconfiguredialog.cpp"
