@@ -8,16 +8,11 @@
 
 #pragma once
 
-#include "kcmutils_version.h"
 #include "kontactkcmultidialog.h"
 #include <QList>
 #include <QStringList>
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-class KCModuleProxy;
-#else
 class KCModule;
-#endif
 class KPageWidgetItem;
 
 class KontactKCMultiDialogPrivate
@@ -31,18 +26,10 @@ protected:
 
     virtual ~KontactKCMultiDialogPrivate() = default;
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KCModuleProxy *currentModule = nullptr;
-#else
     KCModule *currentModule = nullptr;
-#endif
 
     struct CreatedModule {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        KCModuleProxy *kcm = nullptr;
-#else
         KCModule *kcm = nullptr;
-#endif
         KPageWidgetItem *item = nullptr;
         QStringList componentNames;
     };
@@ -59,11 +46,6 @@ protected:
 private:
     void init();
     void apply();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    bool resolveChanges(KCModuleProxy *currentProxy);
-    static bool moduleSave(KCModuleProxy *module);
-#else
     bool resolveChanges(KCModule *currentProxy);
     static bool moduleSave(KCModule *module);
-#endif
 };
